[![PyPi](https://img.shields.io/badge/PyPi-1.0.3-yellow?labelColor=blue&style=flat&logo=pypi&logoColor=yellow&link=https://pypi.org/project/constallation_mmr)](https://pypi.org/project/constallation_mmr)
![Python](https://img.shields.io/badge/Python-3.8-blue?labelColor=yellow&style=flat&logo=python)
![PyPI - Monthly](https://img.shields.io/pypi/dm/constallation_mmr)
![PyPI - Weekly](https://img.shields.io/pypi/dw/constallation_mmr)
![PyPI - Daily](https://img.shields.io/pypi/dd/constallation_mmr)

# Constallation-MMR
Constallation-MMR is a OOP oriented API wrapper part of the greater constallation networking library.

#### Installation
##### Installing With Pip
```shell
pip install constallation_mmr
```
##### Installing With Poetry
```shell
poetry add constallation_mmr
```

## ChangeLogs
- #### 1.0.0
  - added Rig class
  - added method `fetch_rigs`
- #### 1.0.1
  - added method `fetch_rig`
- #### 1.0.2
  - Added method inside class `Rig` for deleting the rig
  - Updated `Rig` class to support credential passthrough
- #### 1.0.3
  - Rewrote `Rig` class properties to handle more verbose output